%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% GPeriodic
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% References:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [ G, GSpat, GSpec ] = GPeriodic(k, x1, x2, d, alpha)

P = 5;
M = 5;
Q = 10;
E = sqrt(pi)/d;

% k = conj(k);


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of Gspectral
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
erfcz = @(z) 1 - ops.erfz(z);

GSpec = 0;
for p=-P:P
    kxp = -alpha + 2*pi*p/d;
    branchCutShift = 0;
    e1 = exp(-branchCutShift*1i);
    e2 = exp(branchCutShift/2*1i);
    kzp = -sqrt((k^2 - kxp^2)*e1)*e2;
    
    term1 = -1/4/d * exp(-1i*kxp*x1)/1i/kzp;
    term2 = exp(1i*kzp*abs(x2)).*erfcz(1i*kzp/2/E + abs(x2)*E);
    term3 = exp(-1i*kzp*abs(x2)).*erfcz(1i*kzp/2/E - abs(x2)*E);
    
    GSpec = GSpec + term1.*(term2+term3);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of Gspatial
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
GSpat = 0;
for m=-M:M
    Rm = sqrt(x2.^2 + (x1-m*d).^2);
    
    term1 = 0;
    Eqp1 = ops.E1((Rm*E).^2);
    for q=0:Q
        term1 = term1 + (k/2/E).^(2*q)./factorial(q).*Eqp1;
        Eqp1 = (exp(-(Rm*E).^2) - (Rm*E).^2.*Eqp1)./(q+1);
    end
    
    term1 = -1/4/pi.*exp(1i*alpha*m*d).*term1;
    
    GSpat = GSpat + term1;
end

G = GSpat + GSpec;
% G = conj(GSpat + GSpec);

end