%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% GradGPeriodic
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% References:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [ G, GradGSpat, GradGSpec ] = GradGPeriodic(k, x1, x2, d, alpha)

P = 5;
M = 5;
Q = 10;
E = sqrt(pi)/d;

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of \nabla Gspectral
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
erfcz = @(z) 1 - ops.erfz(z);
derfcz = @(z) -2/sqrt(pi)*exp(-z.^2);

GradGSpec1 = 0;
GradGSpec2 = 0;
for p=-P:P
    kxp = -alpha + 2*pi*p/d;
    branchCutShift = 0;
    e1 = exp(-branchCutShift*1i);
    e2 = exp(branchCutShift/2*1i);
    kzp = -sqrt((k^2 - kxp^2)*e1)*e2;
    
    term1 = -1/4/d * exp(-1i*kxp*x1)/1i/kzp;
    term2 = -1i*kxp*exp(-1i*kzp*abs(x2)).*erfcz(1i*kzp/2/E - abs(x2)*E) ...
            -1i*kxp*exp(1i*kzp*abs(x2)).*erfcz(1i*kzp/2/E + abs(x2)*E);
    term3 = -1i*kzp*sign(x2).*exp(-1i*kzp*abs(x2)).*erfcz(1i*kzp/2/E - abs(x2)*E) ...
            +1i*kzp*sign(x2).*exp(1i*kzp*abs(x2)).*erfcz(1i*kzp/2/E + abs(x2)*E);
    term4 = -sign(x2)*E.*exp(-1i*kzp*abs(x2)).*derfcz(1i*kzp/2/E - abs(x2)*E) ...
            +sign(x2)*E.*exp(1i*kzp*abs(x2)).*derfcz(1i*kzp/2/E + abs(x2)*E);
        
     GradGSpec1 = GradGSpec1 + term1.*term2;
     GradGSpec2 = GradGSpec2 + term1.*(term3 + term4);
     
end

GradGSpec = [ GradGSpec1 ; GradGSpec2 ];

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of Gspatial
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
GradGSpat1 = 0;
GradGSpat2 = 0;
for m=-M:M
    term1 = E^2/2/pi*(x1-m*d)*exp(1i*alpha*m*d);
    term2 = E^2/2/pi*x2*exp(1i*alpha*m*d);
    
    Rm = sqrt(x2.^2 + (x1-m*d).^2);

    term3 = exp(-(Rm*E).^2)./((Rm*E).^2);
    Eq = ops.E1((Rm*E).^2);
    for q=1:Q
        term3 = term3 + (k/2/E)^(2*q)./factorial(q)*Eq;
        Eq = (exp(-(Rm*E).^2) - (Rm*E).^2.*Eq)./q; 
    end
    
    GradGSpat1 = GradGSpat1 + term1.*term3;
    GradGSpat2 = GradGSpat2 + term2.*term3;
end
GradGSpat = [ GradGSpat1 ; GradGSpat2 ];

G = GradGSpat + GradGSpec;

end