%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% K_QPer_Helm
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% References:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
classdef K_QPer_Helm < ops.Operators
    
    methods
        function obj = K_QPer_Helm(k, D, type, step, d, alpha)
            obj = obj@ops.Operators(D, type, step, D, type, step);
            
            obj.Kmat = ops.K_QPer_Helm.make_kernel_matrix(k, D.points, D.tvec, D.normal, D.avec, D.sigma, d, alpha);
        end
        
    end
    
    methods(Static)
        function K = make_kernel_matrix(k, D, tvec, normal, avec, sigma, d, alpha)
            M = size(D,2);
            K = zeros(M, M);
            
            tvec_norm_square = tvec(1,:).^2 + tvec(2,:).^2;
            
            for j = 1:M
                grad = ops.GradGPeriodic(k, D(1,j)-D(1,:), D(2,j)-D(2,:), d, alpha);
                K(j, :) = (normal(:,j)'*grad).*sigma;
                K(j,j) = -1/4/pi*avec(:,j)'*normal(:,j)/tvec_norm_square(j)*sigma(j);
            end
            %%%%%%%%%%%%%%%%%%%%%%%%
        end
        
        function [ val ] = eval(D, F)
        end
        
    end
end

