%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% SLP_QPer_Helm
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% References:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
classdef SLP_QPer_Helm < ops.Operators
    
    methods
        function obj = SLP_QPer_Helm(k, D1, type1, step1, d, alpha)
            D2 = D1;
            type2 = type1;
            step2 = step1;
            
            obj = obj@ops.Operators(D1, type1, step1, D2, type2, step2);
            obj.Kmat = ops.SLP_QPer_Helm.make_kernel_matrix(k, D1.points, D1.sigma, D1.tvec, d, alpha);
        end
        
    end
    
    methods(Static)
        function K = make_kernel_matrix(k, D, sigma_D, tvec, d, alpha)            
            N = size(D,2);
            K = zeros(N) ;
            
            for i=1:N
                Gi = ops.GPeriodic(k, D(1,i)-D(1,:), D(2,i)-D(2,:), d, alpha);
                K(i,:) = sigma_D.*Gi;             
                K(i,i) = sigma_D(i)*(log(sigma_D(i))-1)/2/pi; %1/2/pi*sigma_D(i)*(log(E*sigma_D(i)/2) - 1);
            end
        end
        
        function [ val ] = eval(D, F, X)
        end
    end
    
end

