%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% DemoQPerHelmholtzG
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Overview:
%   Plot the quasi-periodic Green's function for the Helmholtz
%   equation.
%
% References:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DemoQPerHelmholtzG()
clc, clear all, close all

xMax = 5;
nX = 2^8;
hX = 2*xMax/(nX-1);
[x1, x2] = meshgrid(-xMax:hX:xMax);
d = 1;
k = 2 + 0.5i;
alpha = 0*pi/4;

hFig = figure(1);
set(hFig, 'Position', [100 100 1400 900])
if 1
    field = ops.GPeriodic(k, x1, x2, d, alpha);
    plotField(x1, x2, field)
else
    fieldGrad = ops.GradGPeriodic(k, x1, x2, d, alpha);
    plotFieldGrad(x1, x2, fieldGrad)
end

end

function plotField(x1, x2, field)
subplot(1, 2, 1);
surf(x1, x2, real(field), 'edgecolor', 'none');
xlabel('x_1'); ylabel('x_2'); zlabel('G')
% title('Re(G^{\alpha, \omega})')
view([0 0 90]); rotate3d on; colormap jet; colorbar

subplot(1, 2, 2);
surf(x1, x2, imag(field), 'edgecolor', 'none');
xlabel('x_1'); ylabel('x_2'); zlabel('G')
% title('Im(G^{\alpha, \omega})')
view([0 0 90]); rotate3d on; colormap jet; colorbar
end

function plotFieldGrad(x1, x2, field)
subplot(1, 2, 1);
surf(x1, x2, real(field(1:end/2,:)), 'edgecolor', 'none');
xlabel('x_1'); ylabel('x_2'); zlabel('G')
title('Re(GradG^{\alpha), k})')
view([0 0 90]); rotate3d on; colormap jet; colorbar

subplot(1, 2, 2);
surf(x1, x2, imag(field(1:end/2,:)), 'edgecolor', 'none');
xlabel('x_1'); ylabel('x_2'); zlabel('G')
title('Im(GradG^{\alpha), k})')
view([0 0 90]); rotate3d on; colormap jet; colorbar
end